package pl.edu.agh.scaa.gui;

import java.awt.Color;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingConstants;

public class MenuPanel extends JPanel {

	private static final long serialVersionUID = -1387610650079384056L;

	private final MainWindow mainWindow;

	JButton startButton = new JButton("Start computation");
	JButton stopButton = new JButton("Stop computation");

	private JTextField stepTextField = new JTextField("3000");
	JTextField nTextField = new JTextField("32");
	JTextField deltaTextField = new JTextField("0.001");
	JTextField alphaTextField = new JTextField("0.5");
	JLabel currentStateLabel = new JLabel(" ---- ", JLabel.LEADING);

	public MenuPanel(MainWindow mainWindow) {
		super(new SpringLayout());
		this.mainWindow = mainWindow;
		setBackground(Color.white);
		createPanel();
	}

	public void setCurrentState(String state) {
		currentStateLabel.setText(state);
	}

	public ExecutorParameters getExecutorParameters() {
		return new ExecutorParameters(getStepNum(), getN(), getDelta(), getAlpha());
	}

	private int getStepNum() {
		return Integer.parseInt(stepTextField.getText());
	}

	private int getN() {
		return Integer.parseInt(nTextField.getText());
	}

	private double getDelta() {
		return Double.parseDouble(deltaTextField.getText());
	}

	private double getAlpha() {
		return Double.parseDouble(alphaTextField.getText());
	}

	private void createPanel() {
		add(new JLabel("Steps: ", JLabel.TRAILING));
		add(stepTextField);

		add(new JLabel("Alpha: ", JLabel.TRAILING));
		add(alphaTextField);
		
		add(new JLabel("Delta: ", JLabel.TRAILING));
		add(deltaTextField);
		
		add(new JLabel("n: ", JLabel.TRAILING));
		add(nTextField);
		
		add(new JLabel());
		add(startButton);
		
		add(new JLabel());
		add(stopButton);
		
		add(new JLabel("Step: ", JLabel.TRAILING));
		add(currentStateLabel);
		
		SpringUtilities.makeCompactGrid(this, 
				7, 2,  //rows, cols
				5, 5,  //initialX, initialY
				5, 5); //xPad, yPad
		addListeners();
	}

	private void addListeners() {
		startButton.addActionListener(new StartButtonListener(mainWindow));
		stopButton.addActionListener(new StopButtonListener(mainWindow));

		stepTextField.addKeyListener(new IntTextListener());
		nTextField.addKeyListener(new IntTextListener());

		deltaTextField.addKeyListener(new DoubleTextListener());
		alphaTextField.addKeyListener(new DoubleTextListener());
	}

}
